diff --git a/EgwCoreLib.Lux.Data/Services/ProdService.cs b/EgwCoreLib.Lux.Data/Services/ProdService.cs
index cc2ff6a1..72fd1c16 100644
--- a/EgwCoreLib.Lux.Data/Services/ProdService.cs
+++ b/EgwCoreLib.Lux.Data/Services/ProdService.cs
@@ -87,7 +87,7 @@ namespace EgwCoreLib.Lux.Data.Services
}
///
- /// Restituzione singolo Job specifico
+ /// Restituzione singolo Job specifico dalla coda ORDINI
///
///
///
@@ -396,13 +396,10 @@ namespace EgwCoreLib.Lux.Data.Services
///
/// Chiave hash del contenuto richiesta RUID
///
- public async Task UpdateQueue(string hashKey)
+ public async Task UpdateQueue(Constants.EXECENVIRONMENTS cEnvir, string hashKey)
{
// recupero info accessorie da redis
var tipo = await _db.HashGetAsync(hashKey, "tipo");
- var envir = await _db.HashGetAsync(hashKey, "envir");
- Constants.EXECENVIRONMENTS cEnvir = Constants.EXECENVIRONMENTS.WINDOW;
- Enum.TryParse(envir, out cEnvir);
// verifico SE si tratta di un create/estimate e nel caso processo coda req x sistemare
if (!tipo.IsNull && !string.IsNullOrEmpty(tipo))
diff --git a/Lux.API/Lux.API.csproj b/Lux.API/Lux.API.csproj
index 0deb9ac3..360f70c6 100644
--- a/Lux.API/Lux.API.csproj
+++ b/Lux.API/Lux.API.csproj
@@ -4,7 +4,7 @@
net8.0
enable
enable
- 1.1.2602.0918
+ 1.1.2602.0919
diff --git a/Lux.API/Services/ExternalMessageProcessor.cs b/Lux.API/Services/ExternalMessageProcessor.cs
index b4c4ef08..d25a4a53 100644
--- a/Lux.API/Services/ExternalMessageProcessor.cs
+++ b/Lux.API/Services/ExternalMessageProcessor.cs
@@ -127,7 +127,7 @@ namespace Lux.API.Services
string hKey = await _calcRuidService.CompleteRequestAsync(RUID);
// verifico eventuali spostamenti code calcolo
- await _prodService.UpdateQueue(hKey);
+ await _prodService.UpdateQueue(retData.ExecEnvironment, hKey);
}
// gestione ritorno preview SVG
@@ -216,7 +216,7 @@ namespace Lux.API.Services
}
// sistemo code, definendo nuova key...
string qKey = $"{QuestionModes.ORDER}:{QuestionOrderSubModes.BALANCE}:{UID}.{refGroup}";
- await _prodService.SetDone(qKey, ProdService.QueueType.running);
+ await _prodService.SetDone(retData.ExecEnvironment, qKey, ProdService.QueueType.running);
// reinvio in redis (cache + channel)
await cacheService.SaveProdBalanceAsync(UID, retData.ExecEnvironment, rawBalance);
saved = true;
diff --git a/Resources/ChangeLog.html b/Resources/ChangeLog.html
index 80c51cda..dfb3d006 100644
--- a/Resources/ChangeLog.html
+++ b/Resources/ChangeLog.html
@@ -1,6 +1,6 @@
LUX - Web Windows MES
- Versione: 1.1.2602.0918
+ Versione: 1.1.2602.0919
Note di rilascio:
-
diff --git a/Resources/VersNum.txt b/Resources/VersNum.txt
index 0ab38efc..84a417ea 100644
--- a/Resources/VersNum.txt
+++ b/Resources/VersNum.txt
@@ -1 +1 @@
-1.1.2602.0918
+1.1.2602.0919
diff --git a/Resources/manifest.xml b/Resources/manifest.xml
index 98182a5d..709fdbe3 100644
--- a/Resources/manifest.xml
+++ b/Resources/manifest.xml
@@ -1,6 +1,6 @@
-
- 1.1.2602.0918
+ 1.1.2602.0919
http://nexus.steamware.net/repository/SWS/GPW/stable/GPW.UI.zip
http://nexus.steamware.net/repository/SWS/GPW/stable/ChangeLog.html
false
diff --git a/Lux.API/Controllers/ProdController.cs b/Lux.API/Controllers/ProdController.cs
index 149d2cc1..aa3bb6cb 100644
--- a/Lux.API/Controllers/ProdController.cs
+++ b/Lux.API/Controllers/ProdController.cs
@@ -97,13 +97,17 @@ namespace Lux.API.Controllers
/// Chiamata GET:
/// - fornisce il primo job da eseguire dalla coda (SE presente)
/// - viene registrato come "in corso" e spostato dalla coda richiesta
- /// GET: api/Prod/getnext
+ /// GET: api/Prod/getnext/WINDOW
+ /// GET: api/Prod/getnext/BEAM
///
+ /// Environment della richiesta
///
- [HttpGet("getnext")]
- public async Task> GetNext()
+ [HttpGet("getnext/{envir}")]
+ public async Task> GetNext(string envir)
{
- var result = await PService.GetNext();
+ Constants.EXECENVIRONMENTS cEnvir = Constants.EXECENVIRONMENTS.WINDOW;
+ Enum.TryParse(envir, out cEnvir);
+ var result = await PService.GetNext(cEnvir);
QuestionDTO? deserRes = JsonConvert.DeserializeObject(result);
if (deserRes != null)
{
@@ -116,7 +120,9 @@ namespace Lux.API.Controllers
deserRes.Args.Remove("RUID");
}
// lo aggiungo!
- string envir = $"{deserRes.ExecEnvironment}";
+#if false
+ string envir = $"{deserRes.ExecEnvironment}";
+#endif
var mode = deserRes.Args["Mode"];
var sub = deserRes.Args["SubMode"];
var uid = deserRes.Args["UID"];
@@ -138,7 +144,6 @@ namespace Lux.API.Controllers
///
/// Ritorno calcolo
///
- /// Chiave auth valida (da implementare)
///
///
[HttpPost("jobreturn")]
@@ -189,16 +194,22 @@ namespace Lux.API.Controllers
///
/// Chiamata GET: num richieste in coda (se non specificato รจ waiting, altrimenti )
/// GET: api/Prod/queue-len/
/// GET: api/Prod/queue-len/waiting
/// GET: api/Prod/queue-len/running
///
- /// uid oggetto
+ /// Environment della richiesta
+ /// Tipo coda (default waiting)
///
- [HttpGet("qlen/{type}")]
- public async Task QueueLen(QueueType type = QueueType.waiting)
+ [HttpGet("qlen/{envir}/{type}")]
+ public async Task QueueLen(string envir, QueueType type = QueueType.waiting)
{
- var result = await PService.QueueLen(type);
+ Constants.EXECENVIRONMENTS cEnvir = Constants.EXECENVIRONMENTS.WINDOW;
+ Enum.TryParse(envir, out cEnvir);
+ var result = await PService.QueueLen(cEnvir, type);
return Ok(result);
}
@@ -206,16 +217,18 @@ namespace Lux.API.Controllers
/// Chiamata GET: dizionario stato richieste
/// GET: api/Prod/queue-status/
///
- /// uid oggetto
+ /// Environment della richiesta
///
[HttpGet("qstatus")]
- public async Task QueueStatus()
+ public async Task QueueStatus(string envir)
{
Stopwatch sw = new Stopwatch();
sw.Start();
+ Constants.EXECENVIRONMENTS cEnvir = Constants.EXECENVIRONMENTS.WINDOW;
+ Enum.TryParse(envir, out cEnvir);
Dictionary queueStatus = new Dictionary();
- long numWait = await PService.QueueLen(QueueType.waiting);
- long numRun = await PService.QueueLen(QueueType.running);
+ long numWait = await PService.QueueLen(cEnvir, QueueType.waiting);
+ long numRun = await PService.QueueLen(cEnvir, QueueType.running);
// simulo status...
queueStatus.Add("waiting", numWait);
queueStatus.Add("running", numRun);
@@ -189,16 +194,22 @@ namespace Lux.API.Controllers
///
/// Chiamata GET: num richieste in coda (se non specificato รจ waiting, altrimenti )
- /// GET: api/Prod/queue-len/
- /// GET: api/Prod/queue-len/waiting
- /// GET: api/Prod/queue-len/running
+ /// GET: api/Prod/queue-len/WINDOW/
+ /// GET: api/Prod/queue-len/WINDOW/waiting
+ /// GET: api/Prod/queue-len/WINDOW/running
+ /// GET: api/Prod/queue-len/BEAM/
+ /// GET: api/Prod/queue-len/BEAM/waiting
+ /// GET: api/Prod/queue-len/BEAM/running
///